@@ -648,6 +648,12 @@ gail_button_get_n_children (AtkObject* obj)
      */
     return 0;
 
+  /*
+   * Check whether we have an attached menu for PanelMenuButton
+   */
+  if (g_object_get_data (G_OBJECT (widget), "gtk-attached-menu"))
+    return 1;
+
   n_children = get_n_labels_from_button (widget);
   if (n_children <= 1)
     n_children = 0;
@@ -660,6 +666,7 @@ gail_button_ref_child (AtkObject *obj,
                        gint      i)
 {
   GtkWidget *widget;
+  GtkWidget *child_widget;
   AtkObject *child;
 
   g_return_val_if_fail (GAIL_IS_BUTTON (obj), NULL);
@@ -671,17 +678,27 @@ gail_button_ref_child (AtkObject *obj,
      */
     return NULL;
 
-  child = NULL;
-  if (get_n_labels_from_button (widget) > 1)
+  if (i == 0)
+    child_widget = g_object_get_data (G_OBJECT (widget), "gtk-attached-menu");
+  else
+    child_widget = NULL;
+
+  if (!child_widget) 
     {
-      widget = get_label_from_button (widget, i, TRUE);
-      if (widget)
+      if (get_n_labels_from_button (widget) > 1)
         {
-          child = gtk_widget_get_accessible (widget);
-          g_object_ref (child);
+          child_widget = get_label_from_button (widget, i, TRUE);
         }
     }
 
+  if (child_widget)
+    {
+      child = gtk_widget_get_accessible (child_widget);
+      g_object_ref (child);
+    }
+  else
+    child = NULL;
+
   return child;
 }
 
