@@ -232,6 +232,28 @@ gail_item_get_name (AtkObject *obj)
       label = get_label_from_item (widget);
       if (GTK_IS_LABEL (label))
 	return gtk_label_get_text (GTK_LABEL(label));
+      /*
+       * If we have a menu item in a menu attached to a GtkOptionMenu
+       * the label of the selected item is detached from the menu item
+       */
+      else if (GTK_IS_MENU_ITEM (widget))
+         {
+           GtkWidget *parent;
+           GtkWidget *attach;
+
+           parent = gtk_widget_get_parent (widget);
+           if (GTK_IS_MENU (parent))
+             {
+               attach = gtk_menu_get_attach_widget (GTK_MENU (parent)); 
+
+               if (GTK_IS_OPTION_MENU (attach))
+                 {
+                   label = get_label_from_item (attach);
+                   if (GTK_IS_LABEL (label))
+	             return gtk_label_get_text (GTK_LABEL(label));
+                 }
+             }
+         }
 
       return NULL;
     }
